@@ -1,33 +1,18 @@
-/*
-
-Copyright (c) 2008-2009, Evgeni A. Nurminski
-Copyright (c) 2008-2009, Pete Gonzalez
-
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 3 of the License, or
-(at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this software; see the file COPYING.  If not, see
-<http://www.gnu.org/licenses/>.
-
-
-Authors:
-
-Evgeni A. Nurminski <nurmi@dvo.ru>
-Institute for Automation and Control Problems
-Far East branch of RAS, Vladivostok, Russia
-
-Pete Gonzalez <pgonzalez@bluel.com>
-Bluel Technologies Corporation
-
-*/
+// Copyright (c) 2008-2009, Evgeni A. Nurminski <nurmi@dvo.ru>
+// Copyright (c) 2008-2009, Pete Gonzalez <pgonzalez@bluel.com>
+//
+// This program is free software; you can redistribute it and/or modify it under
+// the terms of the GNU General Public License as published by the Free Software
+// Foundation; either version 3 of the License, or (at your option) any later
+// version.
+//
+// This program is distributed in the hope that it will be useful, but WITHOUT
+// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+// FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
+// details.
+//
+// You should have received a copy of the GNU General Public License along with
+// this program; if not, see <http://www.gnu.org/licenses/>.
 
 #include <octave/oct.h>
 
@@ -45,29 +30,46 @@ void cl2bp_log(const char *message) {
 
 DEFUN_DLD (cl2bp, args, ,
   "-*- texinfo -*-\n\
-@deftypefn {Loadable Function} {@var{h} =} cl2bp (@var{m}, @var{w1}, @var{w2}, @var{up}, @var{lo}\
- [, @var{gridsize}])\n\
+@deftypefn  {Loadable Function} {@var{h} =} cl2bp (@var{m}, @var{w1}, @var{w2}, @var{up}, @var{lo})\n\
+@deftypefnx {Loadable Function} {@var{h} =} cl2bp (@var{m}, @var{w1}, @var{w2}, @var{up}, @var{lo}, @var{gridsize})\n\
+\n\
+Constrained L2 bandpass FIR filter design.  This is a fast implementation of\n\
+the algorithm cited below.  Compared to @dfn{remez}, it offers implicit\n\
+specification of transition bands, a higher likelihood of convergence, and an\n\
+error criterion combining features of both L2 and Chebyshev approaches.\n\
+\n\
+Inputs:\n\
+\n\
+@table @var\n\
+@item m\n\
+degree of cosine polynomial, i.e. the number of output coefficients will be\n\
+@var{m}*2+1\n\
+@item  w1\n\
+@itemx w2\n\
+bandpass filter cutoffs in the range 0 <= @var{w1} < @var{w2} <= pi,\n\
+where pi is the Nyquist frequency\n\
+@item up\n\
+vector of 3 upper bounds for [stopband1, passband, stopband2]\n\
+@item lo\n\
+vector of 3 lower bounds for [stopband1, passband, stopband2]\n\
+@item gridsize\n\
+search grid size; larger values may improve accuracy,\n\
+but greatly increase calculation time.\n\
+@end table\n\
+\n\
+Output:\n\
+\n\
+A vector of @var{m}*2+1 FIR coefficients, or an empty value if the solver\n\
+failed to converge.\n\
 \n\
-Constrained L2 bandpass FIR filter design.  This is a fast implementation of the algorithm\n\
-cited below.  Compared to @dfn{remez}, it offers implicit specification of transition bands,\n\
-a higher likelihood of convergence, and an error criterion combining features of both L2 and\n\
-Chebyshev approaches.@*\n\
-Inputs:@*\n\
-@var{m}: degree of cosine polynomial, i.e. the number of output coefficients will be @var{m}*2+1@*\n\
-@var{w1}, @var{w2}: bandpass filter cutoffs in the range 0 <= @var{w1} < @var{w2} <= pi,\n\
-where pi is the Nyquist frequency@*\n\
-@var{up}: vector of 3 upper bounds for [stopband1, passband, stopband2]@*\n\
-@var{lo}: vector of 3 lower bounds for [stopband1, passband, stopband2]@*\n\
-@var{gridsize}: search grid size; larger values may improve accuracy,\n\
-but greatly increase calculation time.@*\n\
-Output:@*\n\
-A vector of @var{m}*2+1 FIR coefficients, or an empty value if the solver failed to converge.@*\n\
 Example:\n\
 @example\n\
 @code{h = cl2bp(30, 0.3*pi, 0.6*pi, [0.02, 1.02, 0.02], [-0.02, 0.98, -0.02], 2^11);}\n\
 @end example\n\
-Original Paper:  I. W. Selesnick, M. Lang, and C. S. Burrus.  A modified algorithm for\n\
-constrained least square design of multiband FIR filters without specified transition bands.\n\
+\n\
+Original Paper:  I. W. Selesnick, M. Lang, and C. S. Burrus.  A modified\n\
+algorithm for constrained least square design of multiband FIR filters without\n\
+specified transition bands.\n\
 IEEE Trans. on Signal Processing, 46(2):497-501, February 1998.\n\
 @end deftypefn\n\
 @seealso{remez}\n")
@@ -126,7 +128,7 @@ IEEE Trans. on Signal Processing, 46(2):497-501, February 1998.\n\
     error("cl2bp: The \"gridsize\" parameter cannot exceed 1000000");
     return retval;
   }
-  
+
   MallocArray<double> h;
   try {
     cl2bp(h, m, w1, w2, up, lo, L, 1.e-5, 20, cancel_handler);
@@ -163,5 +165,4 @@ IEEE Trans. on Signal Processing, 46(2):497-501, February 1998.\n\
 %!    0.0563980420304213
 %!    0.0000000000000000];
 %! assert(cl2bp(7, 0.25*pi, 0.75*pi, [0.01, 1.04, 0.01], [-0.01, 0.96, -0.01], 2^11), b, 1e-14);
-
 */
